==> texmacs_1.0.7.3.orig.tar.gz: TeXmacs-1.0.7.3-src/TeXmacs/packages/standard/std-symbol.ts <==
<TeXmacs|1.0.4.2>

<style|source>

<\body>
  <active*|<\src-title>
    <src-package|std-symbol|1.0>

    <\src-purpose>
      Some additional symbols for text mode. This file should become obsolete
      when better support for Unicode will be implemented.
    </src-purpose>

    <src-copyright|1998--2004|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public
      license, version 3 or later|$TEXMACS_PATH/LICENSE>.
      It comes WITHOUT ANY WARRANTY WHATSOEVER.
      You should have received a copy of the license which the software.
      If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <assign|cent|<macro|<active*|<with|font|tc|>>>>

  <assign|currency|<macro|<active*|<with|font|tc|>>>>

  <assign|yen|<macro|<active*|<with|font|tc|>>>>

  <assign|copyright|<macro|<active*|<with|font|tcx|>>>>

  <assign|copyleft|<macro|<active*|<with|font|tcx|>>>>

  <assign|registered|<macro|<active*|<with|font|tcx|>>>>

  <assign|degreesign|<macro|<active*|<with|font|tc|>>>>

  <assign|twosuperior|<macro|<active*|<with|font|tc|>>>>

  <assign|threesuperior|<macro|<active*|<with|font|tc|>>>>

  <assign|onesuperior|<macro|<active*|<with|font|tc|>>>>

  <assign|mu|<macro|<active*|<with|font|tcx|>>>>

  <assign|paragraphsign|<active*|<macro|<with|font|tc|>>>>

  <assign|onequarter|<macro|<active*|<with|font|tc|>>>>

  <assign|onehalf|<macro|<active*|<with|font|tc|>>>>

  <assign|threequarters|<macro|<active*|<with|font|tc|>>>>

  <assign|euro|<macro|<active*|<with|font|tcx|>>>>

  <assign|trademark|<macro|<active*|<with|font|tcx|>>>>

  <assign|emdash|<macro|<active*|<with|font|roman|\V>>>>

  <assign|masculine|<active*|<rsup|<wide*|o|\<wide-bar\>>>>>

  <assign|ordfeminine|<active*|<rsup|<wide*|a|\<wide-bar\>>>>>

  <assign|varmasculine|<active*|<rsup|o>>>

  <assign|varordfeminine|<active*|<rsup|a>>>

  \;

  <assign|nbsp|<macro|<style-with|src-compact|none|
  <no-break><specific|screen|<resize|<move|<with|color|#A0A0FF|->|-0.3em|>|0em||0em||>>>>>

  \;
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>

==> texmacs_1.0.7.7.orig.tar.gz: TeXmacs-1.0.7.7-src/TeXmacs/packages/standard/std-symbol.ts <==
<TeXmacs|1.0.7.7>

<style|<tuple|source|std>>

<\body>
  <active*|<\src-title>
    <src-package|std-symbol|1.0>

    <\src-purpose>
      Some additional symbols for text mode. This file should become obsolete
      when better support for Unicode will be implemented.
    </src-purpose>

    <src-copyright|1998--2004|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <assign|cent|<macro|<active*|<with|font|tc|>>>>

  <assign|currency|<macro|<active*|<with|font|tc|>>>>

  <assign|yen|<macro|<active*|<with|font|tc|>>>>

  <assign|copyright|<macro|<active*|<with|font|tcx|>>>>

  <assign|copyleft|<macro|<active*|<with|font|tcx|>>>>

  <assign|registered|<macro|<active*|<with|font|tcx|>>>>

  <assign|degreesign|<macro|<active*|<with|font|tc|>>>>

  <assign|twosuperior|<macro|<active*|<with|font|tc|>>>>

  <assign|threesuperior|<macro|<active*|<with|font|tc|>>>>

  <assign|onesuperior|<macro|<active*|<with|font|tc|>>>>

  <assign|mu|<macro|<active*|<with|font|tcx|>>>>

  <assign|paragraphsign|<active*|<macro|<with|font|tc|>>>>

  <assign|onequarter|<macro|<active*|<with|font|tc|>>>>

  <assign|onehalf|<macro|<active*|<with|font|tc|>>>>

  <assign|threequarters|<macro|<active*|<with|font|tc|>>>>

  <assign|euro|<macro|<active*|<with|font|tcx|>>>>

  <assign|trademark|<macro|<active*|<with|font|tcx|>>>>

  <assign|emdash|<macro|<active*|<with|font|roman|\V>>>>

  <assign|masculine|<active*|<rsup|<wide*|o|\<wide-bar\>>>>>

  <assign|ordfeminine|<active*|<rsup|<wide*|a|\<wide-bar\>>>>>

  <assign|varmasculine|<active*|<rsup|o>>>

  <assign|varordfeminine|<active*|<rsup|a>>>

  \;

  <assign|nbsp|<macro| <no-break><specific|screen|<resize|<move|<with|color|#A0A0FF|->|-0.3em|>|0em||0em||>>>>

  <assign|nbhyph|<macro|-<no-break>>>

  \;
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>
